@@ -1,38 +1,36 @@
 #!/usr/local/bin/perl -w
 
 use strict;
-
+use lib '../.';
 use Tk;
 use Tk::Graph; 
 
 my $mw = MainWindow->new;
 
-my $data;
-
-$data = {
-	'one'  => 20,
-	'two' => 15,
-	'three' => 21,
+my $to_register = {
+	'one'  => [0,5,4,8,6,8],
+	'two' => [2,5,9,4,6,2],
+	'three' => [0,5,6,8,6,8],
 };
 
-
+my $data = {
+	'one'  => 3,
+	'two'  => 3,
+	'three'  => 3,
+};
 
 my $ca = $mw->Graph(
-	-type		=> 'Bars',
-	-shadowdepth	=> 4,
-
-	-xlabel		=> 'xlabel',
-	-xformat	=> '%s',
-
-	-ylabel		=> 'ylabel',
-
-	-printvalue	=> '%s: %g',
+	-type	=> 'Line',
+	-max 	=> 10,
+#	-look	=> 10,
 	)->pack(-expand => 1, 
 		-fill => 'both');
 
-$ca->variable($data);	# Auf Daten anzeigen
+$ca->register($to_register);
 
-$mw->after(2000, sub { shuffle($data, $ca) } );
+$ca->variable($data);
+
+# $mw->after(2000, sub { shuffle($data, $ca) } );
 
 MainLoop;
 
@@ -41,7 +39,7 @@ sub shuffle {
 	my $ca = shift || die;
 
 	foreach my $n (keys %$data) {
-		$data->{$n} = int( rand(100) );		
+		$data->{$n} = int( rand(10) );		
 	}
 	$mw->after(1000, sub { shuffle($data, $ca) } );
 }
